/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.type;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.stock.model.Stock;
import nl.cloudfarming.client.stock.model.StockManager;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.lookup.AbstractLookup;
import org.openide.util.lookup.InstanceContent;
import org.openide.util.lookup.ProxyLookup;

public class StockDataObject extends MultiDataObject{

    private InstanceContent ic;
    private Lookup intern;
    private StockManager stockManager;
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.stock.type");    
    
    
    public StockDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);
        
        registerEditor("application/x-agrosense-stock", true);
        this.ic = new InstanceContent();
        this.intern = new AbstractLookup(this.ic);

        stockManager = Lookup.getDefault().lookup(StockManager.class);
        assert stockManager != null : "No StockManager class found in the default lookup, unable to load the DataObject";  
    }

    @Override
    protected Node createNodeDelegate() {
        Stock stock = stockManager.load(getPrimaryFile());
        assert stock != null;
        LOGGER.log(Level.FINE, "StockDataObject loaded {0}", System.identityHashCode(stock));
        ic.add(stock);
        
        LOGGER.log(Level.FINE, "Creating new node delegate for StockDataObject");           
        
        return super.createNodeDelegate();
    }
    
   
    @Override
    public Lookup getLookup() {
        return new ProxyLookup(super.getLookup(), intern);
    }
}
